
{% extends 'admin/base_site.html' %}

{% load i18n crispy_forms_tags %}


{% block extrahead %}
    {{ block.super }}
    <script type="text/javascript" src="{% url 'admin:jsi18n' %}"></script>
    {{ form.media }}
{% endblock %}


{% block content %}
    <p>
        {% trans 'Items count' %}
        ({{ items.count }}):
    </p>

    {% crispy form form.helper %}
{% endblock %}
